@@ -39,13 +39,16 @@ class TestCTFramesetter (TestCase):
                 setter, CFRange(0, 2), None, CGSize(100, 500),
                 None)
         self.assertIsInstance(r, tuple)
-        self.assertEquals(len(r), 2)
+        self.assertEqual(len(r), 2)
 
         size, range = r
 
         self.assertIsInstance(size, CGSize)
         self.assertIsInstance(range, CFRange)
 
+    @min_os_level('10.14')
+    def testMethods10_14(self):
+        self.assertResultIsCFRetained(CTFramesetterCreateWithTypesetter)
 
 
 if __name__ == "__main__":
